{ config, pkgs, ... }:

{
  home.username = "tsv";
  home.homeDirectory = "/home/tsv";

  home.stateVersion = "22.11";

  programs.home-manager.enable = true;
  nixpkgs.config.allowUnfree = true;

  home.sessionVariables = {
    EDITOR = "nvim";
  };

  home.packages = with pkgs; [
    _1password-gui
    aaxtomp3
    anki
    audible-cli
    awscli2
    awsebcli
    bitwarden
    cachix
    calibre
    chromium
    delta                                  # Nice diffing pager for Git
    docker-compose
    firefox
    fzf
    gcc
    git-crypt
    gitflow
    gnumake
    gnupg
    gimp
    heroku
    htop
    kde-gruvbox
    libreoffice
    lshw
    nerdfonts
    ripgrep
    ruby_3_1
    rubyPackages_3_1.dip
    rubyPackages_3_1.solargraph
    slack
    spotify
    thunderbird
    wine
    winetricks
    zoom-us
  ];

  programs.tmux = {
    enable = true;
    plugins = with pkgs.tmuxPlugins; [
      gruvbox
    ];
  };

  programs.neovim = {
    enable = true;
    plugins = with pkgs.vimPlugins; [
      telescope-nvim
      gruvbox-nvim
      nvim-treesitter.withAllGrammars
      nvim-web-devicons
      nvim-tree-lua
      vim-fugitive
      git-messenger-vim
      nvim-lspconfig
      nvim-cmp
      cmp-treesitter
      cmp-path
      cmp-nvim-lsp
      cmp-buffer
      nvim-dap
      nvim-dap-ui
      vimwiki
    ];
  };

  home.file.".bash_profile".source = ./bash_profile;
  home.file.".bashrc".source = ./bashrc;
  home.file.".tmux.conf".source = ./tmux.conf;
  xdg.configFile."git/config".source = ./git/config;
  xdg.configFile."git/config_foxsoft".source = ./git/config_foxsoft;
  xdg.configFile."nvim/init.lua".source = ./nvim/init.lua;
  xdg.configFile."nvim/lua/tsv/remap.lua".source = ./nvim/lua/tsv/remap.lua;
  home.file.".ssh/config".source = ./ssh/config;
  home.file.".LESS_TERMCAP".source = ./LESS_TERMCAP;
  services.syncthing.enable = true;
  services.syncthing.tray = {
    enable = true;
  };
}
